package com.redhat.thermostat.tools.eclipse.plugin.tests.editor;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import com.redhat.thermostat.tools.eclipse.plugin.editor.Converters;
import com.redhat.thermostat.tools.eclipse.plugin.editor.Converters.EmptyStringToNullConverter;
import com.redhat.thermostat.tools.eclipse.plugin.editor.Converters.ListToStringConverter;
import com.redhat.thermostat.tools.eclipse.plugin.editor.Converters.StringToListConverter;

public class ConvertersTest {

    @Test
    public void testListToStringConverterHandlesEmptyList() {
        List<String> input = new ArrayList<>();
        ListToStringConverter converter = new Converters.ListToStringConverter();
        String result = (String) converter.convert(input);
        assertTrue(result.isEmpty());
    }

    @Test
    public void testListToStringConverterWorks() {
        List<String> input = new ArrayList<>();
        input.add("foo");
        input.add("bar");
        input.add("baz");
        ListToStringConverter converter = new Converters.ListToStringConverter();
        String result = converter.convert(input);
        assertEquals("foo bar baz", result);
    }

    @Test
    public void testStringToListConvertHandlesEmptyString() {
        String input = "";
        StringToListConverter converter = new Converters.StringToListConverter();
        List<String> result = converter.convert(input);
        assertNotNull(result);
        assertTrue(result.isEmpty());
    }

    @Test
    public void testStringToListConvertWorks() {
        String input = "foo bar baz";

        StringToListConverter converter = new Converters.StringToListConverter();
        List<String> result = converter.convert(input);

        assertNotNull(result);

        ArrayList<Object> expected = new ArrayList<>();
        expected.add("foo");
        expected.add("bar");
        expected.add("baz");
        assertEquals(expected, result);
    }

    @Test
    public void testEmptyStringToNullConverterConvertsEmptyStringToNull() {
        String input = "";
        EmptyStringToNullConverter converter = new Converters.EmptyStringToNullConverter();
        String result = converter.convert(input);
        assertNull(result);
    }

    @Test
    public void testEmptyStringToNulLConverterDoesNotModifyNonEmptyStrings() {
        String input = "foo bar baz";
        EmptyStringToNullConverter converter = new Converters.EmptyStringToNullConverter();
        String result = converter.convert(input);
        assertEquals(result, input);
    }
}
